pub struct MavBatteryStatusFlags(/* private fields */);Expand description
MAVLink bitmask enum MAV_BATTERY_STATUS_FLAGS for development dialect.
Battery status flags for fault, health and state indication.
Implementations
Sourceimpl MavBatteryStatusFlags
impl MavBatteryStatusFlags
Sourcepub const NOT_READY_TO_USE: MavBatteryStatusFlags
pub const NOT_READY_TO_USE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_NOT_READY_TO_USE flag.
The battery is not ready to use (fly). Set if the battery has faults or other conditions that make it unsafe to fly with. Note: It will be the logical OR of other status bits (chosen by the manufacturer/integrator).
Sourcepub const CHARGING: MavBatteryStatusFlags
pub const CHARGING: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_CHARGING flag.
Battery is charging.
Sourcepub const CELL_BALANCING: MavBatteryStatusFlags
pub const CELL_BALANCING: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_CELL_BALANCING flag.
Battery is cell balancing (during charging). Not ready to use (MAV_BATTERY_STATUS_FLAGS_NOT_READY_TO_USE may be set).
Sourcepub const FAULT_CELL_IMBALANCE: MavBatteryStatusFlags
pub const FAULT_CELL_IMBALANCE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_CELL_IMBALANCE flag.
Battery cells are not balanced. Not ready to use.
Sourcepub const AUTO_DISCHARGING: MavBatteryStatusFlags
pub const AUTO_DISCHARGING: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_AUTO_DISCHARGING flag.
Battery is auto discharging (towards storage level). Not ready to use (MAV_BATTERY_STATUS_FLAGS_NOT_READY_TO_USE would be set).
Sourcepub const REQUIRES_SERVICE: MavBatteryStatusFlags
pub const REQUIRES_SERVICE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_REQUIRES_SERVICE flag.
Battery requires service (not safe to fly). This is set at vendor discretion. It is likely to be set for most faults, and may also be set according to a maintenance schedule (such as age, or number of recharge cycles, etc.).
Sourcepub const BAD_BATTERY: MavBatteryStatusFlags
pub const BAD_BATTERY: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_BAD_BATTERY flag.
Battery is faulty and cannot be repaired (not safe to fly). This is set at vendor discretion. The battery should be disposed of safely.
Sourcepub const PROTECTIONS_ENABLED: MavBatteryStatusFlags
pub const PROTECTIONS_ENABLED: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_PROTECTIONS_ENABLED flag.
Automatic battery protection monitoring is enabled. When enabled, the system will monitor for certain kinds of faults, such as cells being over-voltage. If a fault is triggered then and protections are enabled then a safety fault (MAV_BATTERY_STATUS_FLAGS_FAULT_PROTECTION_SYSTEM) will be set and power from the battery will be stopped. Note that battery protection monitoring should only be enabled when the vehicle is landed. Once the vehicle is armed, or starts moving, the protections should be disabled to prevent false positives from disabling the output.
Sourcepub const FAULT_PROTECTION_SYSTEM: MavBatteryStatusFlags
pub const FAULT_PROTECTION_SYSTEM: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_PROTECTION_SYSTEM flag.
The battery fault protection system had detected a fault and cut all power from the battery. This will only trigger if MAV_BATTERY_STATUS_FLAGS_PROTECTIONS_ENABLED is set. Other faults like MAV_BATTERY_STATUS_FLAGS_FAULT_OVER_VOLT may also be set, indicating the cause of the protection fault.
Sourcepub const FAULT_OVER_VOLT: MavBatteryStatusFlags
pub const FAULT_OVER_VOLT: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_OVER_VOLT flag.
One or more cells are above their maximum voltage rating.
Sourcepub const FAULT_UNDER_VOLT: MavBatteryStatusFlags
pub const FAULT_UNDER_VOLT: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_UNDER_VOLT flag.
One or more cells are below their minimum voltage rating. A battery that had deep-discharged might be irrepairably damaged, and set both MAV_BATTERY_STATUS_FLAGS_FAULT_UNDER_VOLT and MAV_BATTERY_STATUS_FLAGS_BAD_BATTERY.
Sourcepub const FAULT_OVER_TEMPERATURE: MavBatteryStatusFlags
pub const FAULT_OVER_TEMPERATURE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_OVER_TEMPERATURE flag.
Over-temperature fault.
Sourcepub const FAULT_UNDER_TEMPERATURE: MavBatteryStatusFlags
pub const FAULT_UNDER_TEMPERATURE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_UNDER_TEMPERATURE flag.
Under-temperature fault.
Sourcepub const FAULT_OVER_CURRENT: MavBatteryStatusFlags
pub const FAULT_OVER_CURRENT: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_OVER_CURRENT flag.
Over-current fault.
Sourcepub const FAULT_SHORT_CIRCUIT: MavBatteryStatusFlags
pub const FAULT_SHORT_CIRCUIT: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_SHORT_CIRCUIT flag.
Short circuit event detected. The battery may or may not be safe to use (check other flags).
Sourcepub const FAULT_INCOMPATIBLE_VOLTAGE: MavBatteryStatusFlags
pub const FAULT_INCOMPATIBLE_VOLTAGE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_INCOMPATIBLE_VOLTAGE flag.
Voltage not compatible with power rail voltage (batteries on same power rail should have similar voltage).
Sourcepub const FAULT_INCOMPATIBLE_FIRMWARE: MavBatteryStatusFlags
pub const FAULT_INCOMPATIBLE_FIRMWARE: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_INCOMPATIBLE_FIRMWARE flag.
Battery firmware is not compatible with current autopilot firmware.
Sourcepub const FAULT_INCOMPATIBLE_CELLS_CONFIGURATION: MavBatteryStatusFlags
pub const FAULT_INCOMPATIBLE_CELLS_CONFIGURATION: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_FAULT_INCOMPATIBLE_CELLS_CONFIGURATION flag.
Battery is not compatible due to cell configuration (e.g. 5s1p when vehicle requires 6s).
Sourcepub const CAPACITY_RELATIVE_TO_FULL: MavBatteryStatusFlags
pub const CAPACITY_RELATIVE_TO_FULL: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_CAPACITY_RELATIVE_TO_FULL flag.
Battery capacity_consumed and capacity_remaining values are relative to a full battery (they sum to the total capacity of the battery). This flag would be set for a smart battery that can accurately determine its remaining charge across vehicle reboots and discharge/recharge cycles. If unset the capacity_consumed indicates the consumption since vehicle power-on, as measured using a power monitor. The capacity_remaining, if provided, indicates the estimated remaining capacity on the assumption that the battery was full on vehicle boot. If unset a GCS is recommended to advise that users fully charge the battery on power on.
Sourcepub const EXTENDED: MavBatteryStatusFlags
pub const EXTENDED: MavBatteryStatusFlags
MAV_BATTERY_STATUS_FLAGS_EXTENDED flag.
Reserved (not used). If set, this will indicate that an additional status field exists for higher status values.
Sourceimpl MavBatteryStatusFlags
impl MavBatteryStatusFlags
Sourcepub const fn empty() -> MavBatteryStatusFlags
pub const fn empty() -> MavBatteryStatusFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> MavBatteryStatusFlags
pub const fn all() -> MavBatteryStatusFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<MavBatteryStatusFlags>
pub const fn from_bits(bits: u32) -> Option<MavBatteryStatusFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> MavBatteryStatusFlags
pub const fn from_bits_truncate(bits: u32) -> MavBatteryStatusFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> MavBatteryStatusFlags
pub const fn from_bits_retain(bits: u32) -> MavBatteryStatusFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MavBatteryStatusFlags>
pub fn from_name(name: &str) -> Option<MavBatteryStatusFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MavBatteryStatusFlags) -> bool
pub const fn intersects(&self, other: MavBatteryStatusFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: MavBatteryStatusFlags) -> bool
pub const fn contains(&self, other: MavBatteryStatusFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: MavBatteryStatusFlags)
pub fn insert(&mut self, other: MavBatteryStatusFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: MavBatteryStatusFlags)
pub fn remove(&mut self, other: MavBatteryStatusFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MavBatteryStatusFlags)
pub fn toggle(&mut self, other: MavBatteryStatusFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: MavBatteryStatusFlags, value: bool)
pub fn set(&mut self, other: MavBatteryStatusFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: MavBatteryStatusFlags,
) -> MavBatteryStatusFlags
pub const fn intersection( self, other: MavBatteryStatusFlags, ) -> MavBatteryStatusFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: MavBatteryStatusFlags) -> MavBatteryStatusFlags
pub const fn union(self, other: MavBatteryStatusFlags) -> MavBatteryStatusFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: MavBatteryStatusFlags,
) -> MavBatteryStatusFlags
pub const fn difference( self, other: MavBatteryStatusFlags, ) -> MavBatteryStatusFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: MavBatteryStatusFlags,
) -> MavBatteryStatusFlags
pub const fn symmetric_difference( self, other: MavBatteryStatusFlags, ) -> MavBatteryStatusFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> MavBatteryStatusFlags
pub const fn complement(self) -> MavBatteryStatusFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl MavBatteryStatusFlags
impl MavBatteryStatusFlags
Sourcepub const fn iter(&self) -> Iter<MavBatteryStatusFlags> ⓘ
pub const fn iter(&self) -> Iter<MavBatteryStatusFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MavBatteryStatusFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<MavBatteryStatusFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.