pub struct RadioRcChannelsFlags(/* private fields */);Expand description
MAVLink bitmask enum RADIO_RC_CHANNELS_FLAGS for development dialect.
RADIO_RC_CHANNELS flags (bitmask).
Implementations
Sourceimpl RadioRcChannelsFlags
impl RadioRcChannelsFlags
Sourcepub const FAILSAFE: RadioRcChannelsFlags
pub const FAILSAFE: RadioRcChannelsFlags
RADIO_RC_CHANNELS_FLAGS_FAILSAFE flag.
Failsafe is active. The content of the RC channels data in the RADIO_RC_CHANNELS message is implementation dependent.
Sourcepub const OUTDATED: RadioRcChannelsFlags
pub const OUTDATED: RadioRcChannelsFlags
RADIO_RC_CHANNELS_FLAGS_OUTDATED flag.
Channel data may be out of date. This is set when the receiver is unable to validate incoming data from the transmitter and has therefore resent the last valid data it received.
Sourceimpl RadioRcChannelsFlags
impl RadioRcChannelsFlags
Sourcepub const fn empty() -> RadioRcChannelsFlags
pub const fn empty() -> RadioRcChannelsFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> RadioRcChannelsFlags
pub const fn all() -> RadioRcChannelsFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<RadioRcChannelsFlags>
pub const fn from_bits(bits: u8) -> Option<RadioRcChannelsFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> RadioRcChannelsFlags
pub const fn from_bits_truncate(bits: u8) -> RadioRcChannelsFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> RadioRcChannelsFlags
pub const fn from_bits_retain(bits: u8) -> RadioRcChannelsFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RadioRcChannelsFlags>
pub fn from_name(name: &str) -> Option<RadioRcChannelsFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RadioRcChannelsFlags) -> bool
pub const fn intersects(&self, other: RadioRcChannelsFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: RadioRcChannelsFlags) -> bool
pub const fn contains(&self, other: RadioRcChannelsFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: RadioRcChannelsFlags)
pub fn insert(&mut self, other: RadioRcChannelsFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: RadioRcChannelsFlags)
pub fn remove(&mut self, other: RadioRcChannelsFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RadioRcChannelsFlags)
pub fn toggle(&mut self, other: RadioRcChannelsFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: RadioRcChannelsFlags, value: bool)
pub fn set(&mut self, other: RadioRcChannelsFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: RadioRcChannelsFlags,
) -> RadioRcChannelsFlags
pub const fn intersection( self, other: RadioRcChannelsFlags, ) -> RadioRcChannelsFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: RadioRcChannelsFlags) -> RadioRcChannelsFlags
pub const fn union(self, other: RadioRcChannelsFlags) -> RadioRcChannelsFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(
self,
other: RadioRcChannelsFlags,
) -> RadioRcChannelsFlags
pub const fn difference( self, other: RadioRcChannelsFlags, ) -> RadioRcChannelsFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RadioRcChannelsFlags,
) -> RadioRcChannelsFlags
pub const fn symmetric_difference( self, other: RadioRcChannelsFlags, ) -> RadioRcChannelsFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> RadioRcChannelsFlags
pub const fn complement(self) -> RadioRcChannelsFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RadioRcChannelsFlags
impl RadioRcChannelsFlags
Sourcepub const fn iter(&self) -> Iter<RadioRcChannelsFlags> ⓘ
pub const fn iter(&self) -> Iter<RadioRcChannelsFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RadioRcChannelsFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<RadioRcChannelsFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.