pub type ObstacleDistance = ObstacleDistance;Expand description
Originally defined in common::messages::obstacle_distance.
Aliased Type
pub struct ObstacleDistance {
pub time_usec: u64,
pub sensor_type: MavDistanceSensor,
pub distances: [u16; 72],
pub increment: u8,
pub min_distance: u16,
pub max_distance: u16,
pub increment_f: f32,
pub angle_offset: f32,
pub frame: MavFrame,
}Fields
time_usec: u64MAVLink field time_usec.
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
sensor_type: MavDistanceSensorMAVLink field sensor_type.
Class id of the distance sensor type.
distances: [u16; 72]MAVLink field distances.
Distance of obstacles around the vehicle with index 0 corresponding to north + angle_offset, unless otherwise specified in the frame. A value of 0 is valid and means that the obstacle is practically touching the sensor. A value of max_distance +1 means no obstacle is present. A value of UINT16_MAX for unknown/not used. In a array element, one unit corresponds to 1cm.
increment: u8MAVLink field increment.
Angular width in degrees of each array element. Increment direction is clockwise. This field is ignored if increment_f is non-zero.
min_distance: u16MAVLink field min_distance.
Minimum distance the sensor can measure.
max_distance: u16MAVLink field max_distance.
Maximum distance the sensor can measure.
increment_f: f32MAVLink field increment_f.
Angular width in degrees of each array element as a float. If non-zero then this value is used instead of the uint8_t increment field. Positive is clockwise direction, negative is counter-clockwise.
angle_offset: f32MAVLink field angle_offset.
Relative angle offset of the 0-index element in the distances array. Value of 0 corresponds to forward. Positive is clockwise direction, negative is counter-clockwise.
frame: MavFrameMAVLink field frame.
Coordinate frame of reference for the yaw rotation and offset of the sensor data. Defaults to MAV_FRAME_GLOBAL, which is north aligned. For body-mounted sensors use MAV_FRAME_BODY_FRD, which is vehicle front aligned.