CameraZoomType

Type Alias CameraZoomType 

pub type CameraZoomType = CameraZoomType;
Originally defined in all::enums::camera_zoom_type

Aliased Type

#[repr(u8)]
pub enum CameraZoomType { ZoomTypeStep = 0, ZoomTypeContinuous = 1, ZoomTypeRange = 2, ZoomTypeFocalLength = 3, ZoomTypeHorizontalFov = 4, }

Variants



ZoomTypeStep = 0

MAVLink enum entry ZOOM_TYPE_STEP.

Zoom one step increment (-1 for wide, 1 for tele)



ZoomTypeContinuous = 1

MAVLink enum entry ZOOM_TYPE_CONTINUOUS.

Continuous normalized zoom in/out rate until stopped. Range -1..1, negative: wide, positive: narrow/tele, 0 to stop zooming. Other values should be clipped to the range.



ZoomTypeRange = 2

MAVLink enum entry ZOOM_TYPE_RANGE.

Zoom value as proportion of full camera range (a percentage value between 0.0 and 100.0)



ZoomTypeFocalLength = 3

MAVLink enum entry ZOOM_TYPE_FOCAL_LENGTH.

Zoom value/variable focal length in millimetres. Note that there is no message to get the valid zoom range of the camera, so this can type can only be used for cameras where the zoom range is known (implying that this cannot reliably be used in a GCS for an arbitrary camera)



ZoomTypeHorizontalFov = 4

MAVLink enum entry ZOOM_TYPE_HORIZONTAL_FOV.

Zoom value as horizontal field of view in degrees.