SafetySwitchState

Type Alias SafetySwitchState 

pub type SafetySwitchState = SafetySwitchState;
Originally defined in all::enums::safety_switch_state

Aliased Type

#[repr(u8)]
pub enum SafetySwitchState { Safe = 0, Dangerous = 1, }

Variants



Safe = 0

MAVLink enum entry SAFETY_SWITCH_STATE_SAFE.

Safety switch is engaged and vehicle should be safe to approach.



Dangerous = 1

MAVLink enum entry SAFETY_SWITCH_STATE_DANGEROUS.

Safety switch is NOT engaged and motors, propellers and other actuators should be considered active.