MissionPlan

Struct MissionPlan 

pub struct MissionPlan { /* private fields */ }
Mission plan for drones that support MAVLink mission protocol.

Supports unofficial mission file format.

For no-alloc targets use no_alloc::MissionPlan.

Implementations

Source

impl MissionPlan

pub fn new() -> Self

Creates a new empty mission plan.

pub fn from_waypoints(waypoints: &[Waypoint]) -> Self

Constructs mission plan from the slice waypoints.

pub fn try_from_mission_planner_str(content: &str) -> Result<Self, MissionError>

Attempts to construct mission plan from the contents of the mission file.

pub fn try_from_mission_planner_buf(buf: &[u8]) -> Result<Self, MissionError>

Attempts to construct mission plan from the binary contents of the mission file.

pub fn waypoints(&self) -> &[Waypoint]

Returns a slice of waypoints.

pub fn len(&self) -> usize

Returns the length of available waypoints.

pub fn is_empty(&self) -> bool

Returns true if the list of waypoints is empty.

pub fn put(&mut self, waypoint: Waypoint) -> Option<u16>

Puts waypoint into the mission plan.

This function will either insert a waypoint to an already existing position or append list of waypoints.

pub fn insert(&mut self, waypoint: Waypoint) -> Option<u16>

Inserts waypoint into the mission plan.

This function will insert a waypoint and adjust other waypoint positions accordingly. If the index of a waypoint is greater than length of the current mission plan, it will be ignored.

pub fn push(&mut self, waypoint: Waypoint) -> Option<u16>

Append a new waypoint.

This will update the index field of a Waypoint.

pub fn pop(&mut self) -> Option<Waypoint>

Takes the last Waypoint from the mission list.