pub struct MissionPlan { /* private fields */ }Expand description
⍚ Mission plan for drones that support MAVLink mission
protocol.
Supports unofficial mission file format.
For no-alloc targets use no_alloc::MissionPlan.
Implementations
Sourceimpl MissionPlan
impl MissionPlan
Sourcepub fn from_waypoints(waypoints: &[Waypoint]) -> Self
pub fn from_waypoints(waypoints: &[Waypoint]) -> Self
Constructs mission plan from the slice waypoints.
Sourcepub fn try_from_mission_planner_str(content: &str) -> Result<Self, MissionError>
pub fn try_from_mission_planner_str(content: &str) -> Result<Self, MissionError>
Attempts to construct mission plan from the contents of the mission file.
Sourcepub fn try_from_mission_planner_buf(buf: &[u8]) -> Result<Self, MissionError>
pub fn try_from_mission_planner_buf(buf: &[u8]) -> Result<Self, MissionError>
Attempts to construct mission plan from the binary contents of the mission file.
Sourcepub fn put(&mut self, waypoint: Waypoint) -> Option<u16>
pub fn put(&mut self, waypoint: Waypoint) -> Option<u16>
Puts waypoint into the mission plan.
This function will either insert a waypoint to an already existing position or append list of waypoints.
Sourcepub fn insert(&mut self, waypoint: Waypoint) -> Option<u16>
pub fn insert(&mut self, waypoint: Waypoint) -> Option<u16>
Inserts waypoint into the mission plan.
This function will insert a waypoint and adjust other waypoint positions accordingly. If the
index of a waypoint is greater than length of the current mission plan, it will be
ignored.